<?php

namespace Fbaccount\Fbaccount\Http\Controllers;

use App\Http\Controllers\AdminApiController as AdminController;
use Fbaccount\Fbaccount\Http\Requests\FacebookAccountAdminApiRequest;
use Fbaccount\Fbaccount\Interfaces\FacebookAccountRepositoryInterface;
use Fbaccount\Fbaccount\Models\FacebookAccount;

/**
 * Admin API controller class.
 */
class FacebookAccountAdminApiController extends AdminController
{
    /**
     * Initialize facebook_account controller.
     *
     * @param type FacebookAccountRepositoryInterface $facebook_account
     *
     * @return type
     */
    public function __construct(FacebookAccountRepositoryInterface $facebook_account)
    {
        $this->repository = $facebook_account;
        parent::__construct();
    }

    /**
     * Display a list of facebook_account.
     *
     * @return json
     */
    public function index(FacebookAccountAdminApiRequest $request)
    {
        $facebook_accounts  = $this->repository
            ->setPresenter('\\Fbaccount\\Fbaccount\\Repositories\\Presenter\\FacebookAccountListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $facebook_accounts['code'] = 2000;
        return response()->json($facebook_accounts) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display facebook_account.
     *
     * @param Request $request
     * @param Model   FacebookAccount
     *
     * @return Json
     */
    public function show(FacebookAccountAdminApiRequest $request, FacebookAccount $facebook_account)
    {
        $facebook_account         = $facebook_account->presenter();
        $facebook_account['code'] = 2001;
        return response()->json($facebook_account)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new facebook_account.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(FacebookAccountAdminApiRequest $request, FacebookAccount $facebook_account)
    {
        $facebook_account         = $facebook_account->presenter();
        $facebook_account['code'] = 2002;
        return response()->json($facebook_account)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new facebook_account.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(FacebookAccountAdminApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $facebook_account          = $this->repository->create($attributes);
            $facebook_account          = $facebook_account->presenter();
            $facebook_account['code']  = 2004;

            return response()->json($facebook_account)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
;
        }
    }

    /**
     * Show facebook_account for editing.
     *
     * @param Request $request
     * @param Model   $facebook_account
     *
     * @return json
     */
    public function edit(FacebookAccountAdminApiRequest $request, FacebookAccount $facebook_account)
    {
        $facebook_account         = $facebook_account->presenter();
        $facebook_account['code'] = 2003;
        return response()-> json($facebook_account)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the facebook_account.
     *
     * @param Request $request
     * @param Model   $facebook_account
     *
     * @return json
     */
    public function update(FacebookAccountAdminApiRequest $request, FacebookAccount $facebook_account)
    {
        try {

            $attributes = $request->all();

            $facebook_account->update($attributes);
            $facebook_account         = $facebook_account->presenter();
            $facebook_account['code'] = 2005;

            return response()->json($facebook_account)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the facebook_account.
     *
     * @param Request $request
     * @param Model   $facebook_account
     *
     * @return json
     */
    public function destroy(FacebookAccountAdminApiRequest $request, FacebookAccount $facebook_account)
    {

        try {

            $t = $facebook_account->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('fbaccount::facebook_account.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
