<?php

namespace Fbaccount\Fbaccount\Http\Controllers;

use App\Http\Controllers\PublicApiController as PublicController;
use Fbaccount\Fbaccount\Interfaces\FacebookAccountRepositoryInterface;
use Fbaccount\Fbaccount\Repositories\Presenter\FacebookAccountItemTransformer;

/**
 * Pubic API controller class.
 */
class FacebookAccountPublicApiController extends PublicController
{
    /**
     * Constructor.
     *
     * @param type \Fbaccount\FacebookAccount\Interfaces\FacebookAccountRepositoryInterface $facebook_account
     *
     * @return type
     */
    public function __construct(FacebookAccountRepositoryInterface $facebook_account)
    {
        $this->repository = $facebook_account;
        parent::__construct();
    }

    /**
     * Show facebook_account's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $facebook_accounts = $this->repository
            ->setPresenter('\\Fbaccount\\Fbaccount\\Repositories\\Presenter\\FacebookAccountListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $facebook_accounts['code'] = 2000;
        return response()->json($facebook_accounts)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show facebook_account.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $facebook_account = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($facebook_account)) {
            $facebook_account         = $this->itemPresenter($module, new FacebookAccountItemTransformer);
            $facebook_account['code'] = 2001;
            return response()->json($facebook_account)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
