<?php

namespace Fbaccount\Fbaccount\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Fbaccount\Fbaccount\Models\FacebookAccount;

class FacebookAccountPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the facebook_account.
     *
     * @param User $user
     * @param FacebookAccount $facebook_account
     *
     * @return bool
     */
    public function view(User $user, FacebookAccount $facebook_account)
    {
        if ($user->canDo('fbaccount.facebook_account.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $facebook_account->user_id;
    }

    /**
     * Determine if the given user can create a facebook_account.
     *
     * @param User $user
     * @param FacebookAccount $facebook_account
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('fbaccount.facebook_account.create');
    }

    /**
     * Determine if the given user can update the given facebook_account.
     *
     * @param User $user
     * @param FacebookAccount $facebook_account
     *
     * @return bool
     */
    public function update(User $user, FacebookAccount $facebook_account)
    {
        if ($user->canDo('fbaccount.facebook_account.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $facebook_account->user_id;
    }

    /**
     * Determine if the given user can delete the given facebook_account.
     *
     * @param User $user
     * @param FacebookAccount $facebook_account
     *
     * @return bool
     */
    public function destroy(User $user, FacebookAccount $facebook_account)
    {
        if ($user->canDo('fbaccount.facebook_account.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $facebook_account->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
